@@ -26,7 +26,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: defs.h,v 1.7 1999/11/18 17:26:45 wichert Exp $
+ *	$Id: defs.h,v 1.9 1999/12/23 15:08:17 wichert Exp $
  */
 
 #ifdef linux
@@ -82,7 +82,7 @@
 
 #ifdef SVR4
 #include <sys/procfs.h>
-#ifdef SVR4_MP
+#ifdef HAVE_MP_PROCFS
 #include <sys/uio.h>
 #endif
 #else /* !SVR4 */
@@ -148,7 +148,7 @@ extern int ptrace();
 
 
 #ifdef SVR4
-#ifdef SVR4_MP
+#ifdef HAVE_MP_PROCFS
 extern int mp_ioctl (int f, int c, void *a, int s);
 #define IOCTL(f,c,a)	mp_ioctl (f, c, a, sizeof *a)
 #define IOCTL_STATUS(t) \
@@ -204,7 +204,7 @@ struct tcb {
 	long inst[2];		/* Instructions on above */
 	int pfd;		/* proc file descriptor */
 #ifdef SVR4
-#ifdef SVR4_MP
+#ifdef HAVE_MP_PROCFS
 	int pfd_stat;
 	int pfd_as;
 	pstatus_t status;
@@ -336,6 +336,9 @@ extern void call_summary P((FILE *));
 extern void fake_execve P((struct tcb *, char *, char *[], char *[]));
 extern void printtv32 P((struct tcb*, long));
 
+#ifdef LINUX
+extern int internal_clone P((struct tcb *));
+#endif
 extern int internal_fork P((struct tcb *));
 extern int internal_exec P((struct tcb *));
 extern int internal_wait P((struct tcb *));
