@@ -2,6 +2,7 @@
  * Copyright (c) 1991, 1992 Paul Kranenburg <pk@cs.few.eur.nl>
  * Copyright (c) 1993 Branko Lankester <branko@hacktic.nl>
  * Copyright (c) 1993, 1994, 1995, 1996 Rick Sladkey <jrs@world.std.com>
+ * Copyright (c) 1996-1999 Wichert Akkerman <wichert@cistron.nl>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -26,7 +27,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: file.c,v 1.17 1999/11/18 17:09:47 wichert Exp $
+ *	$Id: file.c,v 1.23 2000/01/11 14:41:10 wichert Exp $
  */
 
 #include "defs.h"
@@ -105,8 +106,10 @@ struct stat {
 #    define loff_t loff_t
 #  endif
 #  define stat libc_stat
+#  define stat64 libc_stat64
 #  include <sys/stat.h>
 #  undef stat
+#  undef stat64
 #else
 #  include <sys/stat.h>
 #endif
@@ -442,7 +445,7 @@ time_t t;
 	}
 	tmp = localtime(&t);
 	sprintf(buf, "%02d/%02d/%02d-%02d:%02d:%02d",
-		tmp->tm_year, tmp->tm_mon + 1, tmp->tm_mday,
+		tmp->tm_year + 1900, tmp->tm_mon + 1, tmp->tm_mday,
 		tmp->tm_hour, tmp->tm_min, tmp->tm_sec);
 	return buf;
 }
@@ -608,6 +611,80 @@ int addr;
 	realprintstat(tcp, &statbuf);
 }
 
+#ifdef STAT64
+static void
+printstat64(tcp, addr)
+struct tcb *tcp;
+int addr;
+{
+	struct stat64 statbuf;
+
+#ifdef LINUXSPARC
+ 	if (current_personality == 1) {
+ 		printstatsol(tcp, addr);
+ 		return;
+ 	}
+#endif /* LINUXSPARC */
+
+	if (!addr) {
+		tprintf("NULL");
+		return;
+	}
+	if (syserror(tcp) || !verbose(tcp)) {
+		tprintf("%#x", addr);
+		return;
+	}
+	if (umove(tcp, addr, &statbuf) < 0) {
+		tprintf("{...}");
+		return;
+	}
+
+	if (!abbrev(tcp)) {
+		tprintf("{st_dev=makedev(%lu, %lu), st_ino=%lu, st_mode=%s, ",
+			(unsigned long) major(statbuf.st_dev),
+			(unsigned long) minor(statbuf.st_dev),
+			(unsigned long) statbuf.st_ino,
+			sprintmode(statbuf.st_mode));
+		tprintf("st_nlink=%lu, st_uid=%lu, st_gid=%lu, ",
+			(unsigned long) statbuf.st_nlink,
+			(unsigned long) statbuf.st_uid,
+			(unsigned long) statbuf.st_gid);
+#ifdef HAVE_ST_BLKSIZE
+		tprintf("st_blksize=%lu, ",
+			(unsigned long) statbuf.st_blksize);
+#endif /* HAVE_ST_BLKSIZE */
+#ifdef HAVE_ST_BLOCKS
+		tprintf("st_blocks=%lu, ", (unsigned long) statbuf.st_blocks);
+#endif /* HAVE_ST_BLOCKS */
+	}
+	else
+		tprintf("{st_mode=%s, ", sprintmode(statbuf.st_mode));
+	switch (statbuf.st_mode & S_IFMT) {
+	case S_IFCHR: case S_IFBLK:
+#ifdef HAVE_ST_RDEV
+		tprintf("st_rdev=makedev(%lu, %lu), ",
+			(unsigned long) major(statbuf.st_rdev),
+			(unsigned long) minor(statbuf.st_rdev));
+#else /* !HAVE_ST_RDEV */
+		tprintf("st_size=makedev(%lu, %lu), ",
+			(unsigned long) major(statbuf.st_size),
+			(unsigned long) minor(statbuf.st_size));
+#endif /* !HAVE_ST_RDEV */
+		break;
+	default:
+		tprintf("st_size=%llu, ", statbuf.st_size);
+		break;
+	}
+	if (!abbrev(tcp)) {
+		tprintf("st_atime=%s, ", sprinttime(statbuf.st_atime));
+		tprintf("st_mtime=%s, ", sprinttime(statbuf.st_mtime));
+		tprintf("st_ctime=%s}", sprinttime(statbuf.st_ctime));
+	}
+	else
+		tprintf("...}");
+}
+#endif /* STAT64 */
+
 #ifdef linux
 static void
 convertoldstat(oldbuf, newbuf)
@@ -628,10 +705,8 @@ struct stat *newbuf;
     newbuf->st_blksize=0;	/* not supported in old_stat */
     newbuf->st_blocks=0;		/* not supported in old_stat */
 }
-#endif
 
 
-#ifdef linux
 static void
 printoldstat(tcp, addr)
 struct tcb *tcp;
@@ -680,6 +755,23 @@ struct tcb *tcp;
 }
 
 #ifdef linux
+int
+sys_stat64(tcp)
+struct tcb *tcp;
+{
+#ifdef HAVE_STAT64
+	if (entering(tcp)) {
+		printpath(tcp, tcp->u_arg[0]);
+		tprintf(", ");
+	} else {
+		printstat64(tcp, tcp->u_arg[1]);
+	}
+	return 0;
+#else
+	return printargs(tcp);
+#endif
+}
+
 int
 sys_oldstat(tcp)
 struct tcb *tcp;
@@ -707,6 +799,22 @@ struct tcb *tcp;
 }
 
 #ifdef linux
+int
+sys_fstat64(tcp)
+struct tcb *tcp;
+{
+#ifdef HAVE_STAT64
+	if (entering(tcp))
+		tprintf("%ld, ", tcp->u_arg[0]);
+	else {
+		printstat64(tcp, tcp->u_arg[1]);
+	}
+	return 0;
+#else
+	return printargs(tcp);
+#endif
+}
+
 int
 sys_oldfstat(tcp)
 struct tcb *tcp;
@@ -734,6 +842,23 @@ struct tcb *tcp;
 }
 
 #ifdef linux
+int
+sys_lstat64(tcp)
+struct tcb *tcp;
+{
+#ifdef HAVE_STAT64
+	if (entering(tcp)) {
+		printpath(tcp, tcp->u_arg[0]);
+		tprintf(", ");
+	} else {
+		printstat64(tcp, tcp->u_arg[1]);
+	}
+	return 0;
+#else
+	return printargs(tcp);
+#endif
+}
+
 int
 sys_oldlstat(tcp)
 struct tcb *tcp;
@@ -825,9 +950,24 @@ struct tcb *tcp;
 #include <sys/acl.h>
 
 struct xlat aclcmds[] = {
+#ifdef SETACL
 	{ SETACL,	"SETACL"	},
+#endif
+#ifdef GETACL
 	{ GETACL,	"GETACL"	},
+#endif
+#ifdef GETACLCNT
 	{ GETACLCNT,	"GETACLCNT"	},
+#endif
+#ifdef ACL_GET
+	{ ACL_GET,	"ACL_GET"	},
+#endif	
+#ifdef ACL_SET
+	{ ACL_SET,	"ACL_SET"	},
+#endif	
+#ifdef ACL_CNT
+	{ ACL_CNT,	"ACL_CNT"	},
+#endif	
 	{ 0,		NULL		},
 };
 
@@ -873,6 +1013,44 @@ struct tcb *tcp;
 	return 0;
 }
 
+
+struct xlat aclipc[] = {
+#ifdef IPC_SHM
+	{ IPC_SHM,	"IPC_SHM"	},
+#endif	
+#ifdef IPC_SEM
+	{ IPC_SEM,	"IPC_SEM"	},
+#endif	
+#ifdef IPC_MSG
+	{ IPC_MSG,	"IPC_MSG"	},
+#endif	
+	{ 0,		NULL		},
+};
+
+
+int
+sys_aclipc(tcp)
+struct tcb *tcp;
+{
+	if (entering(tcp)) {
+		printxval(aclipc, tcp->u_arg[0], "???IPC???");
+		tprintf(", %#lx, ", tcp->u_arg[1]);
+		printxval(aclcmds, tcp->u_arg[2], "???ACL???");
+		tprintf(", %ld", tcp->u_arg[3]);
+		/*
+		 * FIXME - dump out the list of aclent_t's pointed to
+		 * by "tcp->u_arg[4]" if it's not NULL.
+		 */
+		if (tcp->u_arg[4])
+			tprintf(", %#lx", tcp->u_arg[4]);
+		else
+			tprintf(", NULL");
+	}
+	return 0;
+}
+
+
+
 #endif /* HAVE_SYS_ACL_H */
 
 #endif /* SVR4 || LINUXSPARC */
