@@ -25,7 +25,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: dummy.h,v 1.4 1999/05/27 12:00:57 wichert Exp $
+ *	$Id: dummy.h,v 1.5 1999/07/15 21:11:37 wichert Exp $
  */
 
 /* still unfinished */
@@ -35,7 +35,6 @@
 #define	sys_iopl		printargs
 #define	sys_vm86old		printargs
 #define	sys_modify_ldt		printargs
-#define	sys_init_module		printargs
 #define	sys_get_kernel_syms	printargs
 #define	sys_quotactl		printargs
 #define	sys_bdflush		printargs
@@ -62,7 +61,6 @@
 #define	sys_swapon		sys_chdir
 #define	sys_swapoff		sys_chdir
 #define	sys_clone		sys_fork
-#define	sys_create_module	sys_sethostname
 #define	sys_delete_module	sys_chdir
 #define	sys_fchdir		sys_close
 #define	sys_setfsuid		sys_setuid
@@ -206,4 +204,6 @@
 #define	sys_fstat		printargs
 #define	sys_personality		printargs
 #define sys_poll		printargs
+#define	sys_create_module	printargs
+#define	sys_init_module		printargs
 #endif
