@@ -25,7 +25,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: syscallent.h,v 1.3 1999/06/03 14:21:07 wichert Exp $
+ *	$Id: syscallent.h,v 1.6 1999/12/24 08:00:37 drepper Exp $
  */
 
 	{ 0,	0,	sys_setup,		"setup"		}, /* 0 */
@@ -122,7 +122,7 @@
 	{ 1,	TF,	sys_swapon,		"swapon"	}, /* 87 */
 	{ 3,	0,	sys_reboot,		"reboot"	}, /* 88 */
 	{ 3,	0,	sys_readdir,		"readdir"	}, /* 89 */
-	{ 6,	0,	sys_mmap,		"mmap"		}, /* 90 */
+	{ 6,	0,	sys_old_mmap,		"old_mmap"	}, /* 90 */
 	{ 2,	0,	sys_munmap,		"munmap"	}, /* 91 */
 	{ 2,	TF,	sys_truncate,		"truncate"	}, /* 92 */
 	{ 2,	0,	sys_ftruncate,		"ftruncate"	}, /* 93 */
@@ -236,18 +236,18 @@
 	{ 5,	0,	printargs,		"SYS_188"	}, /* 188 */
 	{ 5,	0,	printargs,		"SYS_189"	}, /* 189 */
 	{ 0,	TP,	sys_vfork,		"vfork"		}, /* 190 */
-	{ 5,	0,	printargs,		"SYS_191"	}, /* 191 */
-	{ 5,	0,	printargs,		"SYS_192"	}, /* 192 */
-	{ 5,	0,	printargs,		"SYS_193"	}, /* 193 */
-	{ 5,	0,	printargs,		"SYS_194"	}, /* 194 */
-	{ 5,	0,	printargs,		"SYS_195"	}, /* 195 */
-	{ 5,	0,	printargs,		"SYS_196"	}, /* 196 */
-	{ 5,	0,	printargs,		"SYS_197"	}, /* 197 */
+	{ 5,	0,	printargs,		"getrlimit"	}, /* 191 */
+	{ 6,	0,	sys_mmap,		"mmap2"		}, /* 192 */
+	{ 5,	0,	printargs,		"truncate64"	}, /* 193 */
+	{ 5,	0,	printargs,		"ftruncate64"	}, /* 194 */
+	{ 2,	TF,	sys_stat64,		"stat64"	}, /* 195 */
+	{ 2,	TF,	sys_lstat64,		"lstat64"	}, /* 196 */
+	{ 2,	TF,	sys_fstat64,		"fstat64"	}, /* 197 */
 	{ 5,	0,	printargs,		"SYS_198"	}, /* 198 */
 	{ 5,	0,	printargs,		"SYS_199"	}, /* 199 */
 
 	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 200 */
-	{ 4,	TI,	printargs,		"semop"		}, /* 201 */
+	{ 4,	TI,	sys_semop,		"semop"		}, /* 201 */
 	{ 4,	TI,	sys_semget,		"semget"	}, /* 202 */
 	{ 4,	TI,	sys_semctl,		"semctl"	}, /* 203 */
 	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 204 */
