@@ -2,6 +2,7 @@
  * Copyright (c) 1991, 1992 Paul Kranenburg <pk@cs.few.eur.nl>
  * Copyright (c) 1993 Branko Lankester <branko@hacktic.nl>
  * Copyright (c) 1993, 1994, 1995, 1996 Rick Sladkey <jrs@world.std.com>
+ * Copyright (c) 1996-1999 Wichert Akkerman <wichert@cistron.nl>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -26,7 +27,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: net.c,v 1.10 1999/11/18 17:09:47 wichert Exp $
+ *	$Id: net.c,v 1.12 1999/12/23 14:20:15 wichert Exp $
  */
 
 #include "defs.h"
@@ -45,7 +46,7 @@
 #endif
 #endif /* LINUX */
 
-#if defined(LINUX) && defined(MIPS)
+#if defined (__GLIBC__) && ((__GLIBC__ < 2) || (__GLIBC__ == 2 && __GLIBC_MINOR__ < 1))
 #if defined(HAVE_LINUX_IN6_H)
 #include <linux/in6.h>
 #endif
@@ -141,17 +142,23 @@ static struct xlat addrfams[] = {
 	{ AF_UNSPEC,	"AF_UNSPEC"	},
 	{ AF_UNIX,	"AF_UNIX"	},
 	{ AF_INET,	"AF_INET"	},
+#ifdef AF_INET6
 	{ AF_INET6,	"AF_INET6"	},
+#endif
 	{ AF_DECnet,	"AF_DECnet"	},
 #ifdef PF_ATMSVC
 	{ AF_ATMSVC,	"AF_ATMSVC"	},
 #endif
+#ifdef AF_PACKET
 	{ AF_PACKET,	"AF_PACKET"	},
+#endif
+#ifdef AF_NETLINK
 	{ AF_NETLINK,	"AF_NETLINK"	},
-#ifdef PF_ISO
+#endif
+#ifdef AF_ISO
 	{ AF_ISO,	"AF_ISO"	},
 #endif
-#ifdef PF_IMPLINK
+#ifdef AF_IMPLINK
 	{ AF_IMPLINK,	"AF_IMPLINK"	},
 #endif
 	{ 0,		NULL		},
