@@ -24,13 +24,13 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: proc.c,v 1.3 1999/08/29 23:15:07 wichert Exp $
+ *	$Id: proc.c,v 1.4 1999/11/29 15:34:02 wichert Exp $
  */
 
 #include "defs.h"
 
 #ifdef SVR4
-#ifndef SVR4_MP
+#ifndef HAVE_MP_PROCFS
 
 static struct xlat proc_status_flags[] = {
 	{ PR_STOPPED,	"PR_STOPPED"	},
@@ -183,6 +183,6 @@ int code, arg;
 	}
 }
 
-#endif /* SVR4_MP */
+#endif /* HAVE_MP_PROCFS */
 #endif /* SVR4 */
 
