@@ -2,6 +2,10 @@
  * Copyright (c) 1991, 1992 Paul Kranenburg <pk@cs.few.eur.nl>
  * Copyright (c) 1993 Branko Lankester <branko@hacktic.nl>
  * Copyright (c) 1993, 1994, 1995, 1996 Rick Sladkey <jrs@world.std.com>
+ * Copyright (c) 1996-1999 Wichert Akkerman <wichert@cistron.nl>
+ * Copyright (c) 1999 IBM Deutschland Entwicklung GmbH, IBM Corporation
+ *                     Linux for s390 port by D.J. Barrow
+ *                    <barrow_dj@mail.yahoo.com,djbarrow@de.ibm.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -26,7 +30,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: signal.c,v 1.15 1999/10/31 21:15:38 wichert Exp $
+ *	$Id: signal.c,v 1.18 1999/12/23 14:20:15 wichert Exp $
  */
 
 #include "defs.h"
@@ -628,8 +632,12 @@ struct tcb *tcp;
 			}
 #endif /* !SVR4 */
 			tprintf("{%#lx, ", (long) sa.SA_HANDLER);
+#ifndef LINUX
+			printsigmask (&sa.sa_mask, 0);
+#else
 			long_to_sigset(sa.sa_mask, &sigset);
 			printsigmask(&sigset, 0);
+#endif
 			tprintf(", ");
 			if (!printflags(sigact_flags, sa.sa_flags))
 				tprintf("0");
@@ -688,6 +696,27 @@ int
 sys_sigreturn(tcp)
 struct tcb *tcp;
 {
+#ifdef S390
+    long usp;
+    struct sigcontext_struct sc;
+
+    if (entering(tcp)) {
+	    tcp->u_arg[0] = 0;
+	    if (upeek(tcp->pid,PT_GPR15,&usp)<0)
+		    return 0;
+	    if (umove(tcp, usp+__SIGNAL_FRAMESIZE, &sc) < 0)
+		    return 0;
+	    tcp->u_arg[0] = 1;
+	    memcpy(&tcp->u_arg[1],&sc.oldmask[0],sizeof(sigset_t));
+    } else {
+	    tcp->u_rval = tcp->u_error = 0;
+	    if (tcp->u_arg[0] == 0)
+		    return 0;
+	    tcp->auxstr = sprintsigmask("mask now ",(sigset_t *)&tcp->u_arg[1]);
+	    return RVAL_NONE | RVAL_STR;
+    }
+    return 0;
+#else
 #ifdef I386
 	long esp;
 	struct sigcontext_struct sc;
@@ -839,6 +868,7 @@ struct tcb *tcp;
 #endif /* !M68K */
 #endif /* !POWERPC */
 #endif /* !I386 */
+#endif /* S390 */
 }
 
 int
@@ -884,7 +914,7 @@ struct tcb *tcp;
 		if (umove(tcp, tcp->u_arg[0], &sigset) < 0)
 			tprintf("[?]");
 		else
-			printsigmask(sigset, 0);
+			printsigmask(&sigset, 0);
 	}
 	return 0;
 }
@@ -1111,7 +1141,7 @@ struct tcb *tcp;
 		else if (copy_sigset(tcp, tcp->u_arg[0], &sigset) < 0)
 			tprintf("[?]");
 		else
-			printsigmask(sigset, 0);
+			printsigmask(&sigset, 0);
 	}
 	return 0;
 }
@@ -1313,7 +1343,7 @@ sys_rt_sigpending(tcp)
 					 &sigset, tcp->u_arg[1]) < 0)
 			tprintf("[?]");
 		else
-			printsigmask(sigset, 1);
+			printsigmask(&sigset, 1);
 	}
 	return 0;
 }
@@ -1564,7 +1594,7 @@ int sys_rt_sigtimedwait(tcp)
 				    &sigset, tcp->u_arg[3]) < 0)
 			tprintf("[?]");
 		else
-			printsigmask(sigset, 1);
+			printsigmask(&sigset, 1);
 		tprintf(", ");
 	}
 	else {
