@@ -24,7 +24,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: sock.c,v 1.1.1.1 1999/02/19 00:22:29 wichert Exp $
+ *	$Id: sock.c,v 1.2 1999/05/09 00:29:59 wichert Exp $
  */
 
 #include "defs.h"
@@ -36,8 +36,12 @@
 #endif
 
 #ifdef ALPHA
+#ifdef HAVE_SYS_IOCTL_H
+#include <sys/ioctl.h>
+#elif defined(HAVE_IOCTLS_H)
 #include <ioctls.h>
 #endif
+#endif
 
 int
 sock_ioctl(tcp, code, arg)
