@@ -2,6 +2,7 @@
  * Copyright (c) 1991, 1992 Paul Kranenburg <pk@cs.few.eur.nl>
  * Copyright (c) 1993 Branko Lankester <branko@hacktic.nl>
  * Copyright (c) 1993, 1994, 1995, 1996 Rick Sladkey <jrs@world.std.com>
+ * Copyright (c) 1996-1999 Wichert Akkerman <wichert@cistron.nl>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -26,7 +27,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: strace.c,v 1.8 1999/10/17 00:57:34 wichert Exp $
+ *	$Id: strace.c,v 1.11 1999/12/23 14:20:15 wichert Exp $
  */
 
 #include "defs.h"
@@ -45,7 +46,7 @@
 #ifdef SVR4
 #include <sys/stropts.h>
 #include <poll.h>
-#ifdef SVR4_MP
+#ifdef HAVE_MP_PROCFS
 #include <sys/uio.h>
 #endif
 #endif
@@ -108,7 +109,7 @@ static int proc_poll_pipe[2] = { -1, -1 };
 
 #endif /* !HAVE_POLLABLE_PROCFS */
 
-#ifdef SVR4_MP
+#ifdef HAVE_MP_PROCFS
 #define POLLWANT	POLLWRNORM
 #else
 #define POLLWANT	POLLPRI
@@ -581,7 +582,7 @@ int attaching;
 	static int last_pfd;
 #endif
 
-#ifdef SVR4_MP
+#ifdef HAVE_MP_PROCFS
 	/* Open the process pseudo-files in /proc. */
 	sprintf(proc, "/proc/%d/ctl", tcp->pid);
 	if ((tcp->pfd = open(proc, O_WRONLY|O_EXCL)) < 0) {
@@ -1243,6 +1244,9 @@ choose_pfd()
 static int
 trace()
 {
+#ifdef POLL_HACK
+	struct tcb *in_syscall;
+#endif
 	struct tcb *tcp;
 	int pfd;
 	int what;
@@ -1274,6 +1278,28 @@ trace()
 #endif /* !HAVE_POLLABLE_PROCFS */
 		default:
 #ifdef HAVE_POLLABLE_PROCFS
+#ifdef POLL_HACK
+		        /* On some systems (e.g. UnixWare) we get too much ugly
+			   "unfinished..." stuff when multiple proceses are in
+			   syscalls.  Here's a nasty hack */
+		    
+			if (in_syscall) {
+				struct pollfd pv;
+				tcp = in_syscall;
+				in_syscall = NULL;
+				pv.fd = tcp->pfd;
+				pv.events = POLLWANT;
+				if ((what = poll (&pv, 1, 1)) < 0) {
+					if (interrupted)
+						return 0;
+					continue;
+				}
+				else if (what == 1 && pv.revents & POLLWANT) {
+					goto FOUND;
+				}
+			}
+#endif
+
 			if (poll(pollv, nprocs, INFTIM) < 0) {
 				if (interrupted)
 					return 0;
@@ -1297,6 +1323,7 @@ trace()
 			fprintf(stderr, "unknown pfd: %u\n", pfd);
 			exit(1);
 		}
+	FOUND:
 		/* Get the status of the process. */
 		if (!interrupted) {
 			ioctl_result = IOCTL_WSTOP (tcp);
@@ -1358,6 +1385,9 @@ trace()
 			}
 			break;
 		case PR_SYSENTRY:
+#ifdef POLL_HACK
+		        in_syscall = tcp;
+#endif
 		case PR_SYSEXIT:
 			if (trace_syscall(tcp) < 0) {
 				fprintf(stderr, "syscall trouble\n");
@@ -1707,7 +1737,7 @@ struct tcb *tcp;
 	tcp_last = NULL;
 }
 
-#ifdef SVR4_MP
+#ifdef HAVE_MP_PROCFS
 
 int mp_ioctl (int fd, int cmd, void *arg, int size) {
 
