@@ -24,7 +24,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: syscallent.h,v 1.3 1999/08/29 23:15:09 wichert Exp $
+ *	$Id: syscallent.h,v 1.4 1999/11/26 09:54:08 wichert Exp $
  */
 
 #ifdef MIPS
@@ -368,7 +368,7 @@
 	{ -1,	0,	printargs,		"filepriv"	}, /* 145 */
 	{ -1,	0,	printargs,		"procpriv"	}, /* 146 */
 	{ -1,	0,	printargs,		"devstat"	}, /* 147 */
-	{ -1,	0,	printargs,		"aclipc"	}, /* 148 */
+	{ -1,	0,	sys_aclipc,		"aclipc"	}, /* 148 */
 	{ -1,	0,	printargs,		"fdevstat"	}, /* 149 */
 	{ -1,	0,	printargs,		"flvlfile"	}, /* 150 */
 	{ -1,	0,	printargs,		"lvlfile"	}, /* 151 */
@@ -377,7 +377,7 @@
 	{ -1,	0,	printargs,		"lvlproc"	}, /* 154 */
 	{ -1,	0, 	printargs,		"SYS_155"	}, /* 155 */
 	{ -1,	0,	printargs,		"lvlipc"	}, /* 156 */
-	{ -1,	0,	printargs,		"acl"		}, /* 157 */
+	{ -1,	0,	sys_acl,		"acl"		}, /* 157 */
 	{ -1,	0,	printargs,		"auditevt"	}, /* 158 */
 	{ -1,	0,	printargs,		"auditctl"	}, /* 159 */
 	{ -1,	0,	printargs,		"auditdmp"	}, /* 160 */
