@@ -2,6 +2,10 @@
  * Copyright (c) 1991, 1992 Paul Kranenburg <pk@cs.few.eur.nl>
  * Copyright (c) 1993 Branko Lankester <branko@hacktic.nl>
  * Copyright (c) 1993, 1994, 1995, 1996 Rick Sladkey <jrs@world.std.com>
+ * Copyright (c) 1996-1999 Wichert Akkerman <wichert@cistron.nl>
+ * Copyright (c) 1999 IBM Deutschland Entwicklung GmbH, IBM Corporation
+ *                     Linux for s390 port by D.J. Barrow
+ *                    <barrow_dj@mail.yahoo.com,djbarrow@de.ibm.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -26,7 +30,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: util.c,v 1.11 1999/10/31 21:15:38 wichert Exp $
+ *	$Id: util.c,v 1.16 1999/12/24 23:19:31 wakkerma Exp $
  */
 
 #include "defs.h"
@@ -624,7 +628,7 @@ char *laddr;
 #endif /* SUNOS4 */
 
 #ifdef SVR4
-#ifdef SVR4_MP
+#ifdef HAVE_MP_PROCFS
 	if (pread(tcp->pfd_as, laddr, len, addr) == -1)
 		return -1;
 #else
@@ -643,7 +647,7 @@ char *laddr;
 	if (read(tcp->pfd, laddr, len) == -1)
 		return -1;
 #endif /* !HAVE_PREAD */
-#endif /* SVR4_MP */
+#endif /* HAVE_MP_PROCFS */
 #endif /* SVR4 */
 
 	return 0;
@@ -867,7 +871,6 @@ struct tcb *tcp;
 
 #ifdef LINUX
 	long pc;
-
 #if defined(I386)
 	if (upeek(tcp->pid, 4*EIP, &pc) < 0)
 		return -1;
@@ -891,6 +894,8 @@ struct tcb *tcp;
 	if (ptrace(PTRACE_GETREGS,tcp->pid,(char *)&regs,0) < 0)
 		return -1;
 	pc = regs.r_pc;
+#elif defined(S390)
+	if(upeek(tcp->pid,PT_PSWADDR,&pc) < 0)
 #endif
 	return pc;
 #endif /* LINUX */
@@ -1045,13 +1050,15 @@ struct tcb *tcp;
 #elif defined (M68K)
 #define LOOP	0x60fe0000
 #elif defined (ALPHA)
-#define LOOP    0xc3ffffff
+#define LOOP	0xc3ffffff
 #elif defined (POWERPC)
-#define LOOP 0x0000feeb
+#define LOOP	0x0000feeb
 #elif defined(ARM)
-#define LOOP -1  /* almost certainly wrong, jws */
+#define LOOP	0xEAFFFFFE
 #elif defined(MIPS)
-#define LOOP 0x1000ffff
+#define LOOP	0x1000ffff
+#elif defined(S390)
+#define LOOP	0xa7f40000	/* BRC 15,0 */
 #else
 #error unknown architecture
 #endif
@@ -1075,6 +1082,9 @@ struct tcb *tcp;
 #elif defined (POWERPC)
 	if (upeek(tcp->pid, 4*PT_NIP, &tcp->baddr) < 0)
 		return -1;
+#elif defined(S390)
+	if (upeek(tcp->pid,PT_PSWADDR, &tcp->baddr) < 0)
+		return -1;
 #else
 #error unknown architecture
 #endif
